simplify.Jws

Package simplify :: Class Jws |
[hide private]
[frames] | no frames]

# Class Jws

source code

Instance Methods | [hide private]
__init__(self) | source code
sign(self, private_api_key, msg) | source code
verify(self, header, url, public_api_key) | source code
safe_base64_decode(self, url) | source code
encode_json(self, json_str) | source code

Static Methods | [hide private]
encode(url, auth, params, has_payload) | source code
auth_encode(url, auth, params) | source code
decode(params, auth) | source code

Class Variables | [hide private]
| NUM_HEADERS = `7`
| ALGORITHM = `'HS256'`
| TYPE = `'JWS'`
| HDR_URI = `'api.simplifycommerce.com/uri'`
| HDR_TIMESTAMP = `'api.simplifycommerce.com/timestamp'`
| HDR_NONCE = `'api.simplifycommerce.com/nonce'`
| HDR_TOKEN = `"api.simplifycommerce.com/token"`
| HDR_UNAME = `'uname'`
| HDR_ALGORITHM = `'alg'`
| HDR_TYPE = `'typ'`
| HDR_KEY_ID = `'kid'`
| TIMESTAMP_MAX_DIFF = `1000* 60* 5`